@@ -354,7 +354,7 @@ error:
 static PyObject *
 psutil_net_if_mtu(PyObject *self, PyObject *args) {
     char *nic_name;
-    int sock = 0;
+    int sock = -1;
     int ret;
 #ifdef PSUTIL_SUNOS10
     struct lifreq lifr;
@@ -387,7 +387,7 @@ psutil_net_if_mtu(PyObject *self, PyObject *args) {
 #endif
 
 error:
-    if (sock != 0)
+    if (sock != -1)
         close(sock);
     return PyErr_SetFromErrno(PyExc_OSError);
 }
@@ -401,7 +401,7 @@ error:
 static PyObject *
 psutil_net_if_flags(PyObject *self, PyObject *args) {
     char *nic_name;
-    int sock = 0;
+    int sock = -1;
     int ret;
     struct ifreq ifr;
 
@@ -424,7 +424,7 @@ psutil_net_if_flags(PyObject *self, PyObject *args) {
         return Py_BuildValue("O", Py_False);
 
 error:
-    if (sock != 0)
+    if (sock != -1)
         close(sock);
     return PyErr_SetFromErrno(PyExc_OSError);
 }
@@ -579,7 +579,7 @@ int psutil_get_nic_speed(int ifm_active) {
 static PyObject *
 psutil_net_if_duplex_speed(PyObject *self, PyObject *args) {
     char *nic_name;
-    int sock = 0;
+    int sock = -1;
     int ret;
     int duplex;
     int speed;
@@ -591,7 +591,7 @@ psutil_net_if_duplex_speed(PyObject *self, PyObject *args) {
 
     sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock == -1)
-        goto error;
+        return PyErr_SetFromErrno(PyExc_OSError);
     strncpy(ifr.ifr_name, nic_name, sizeof(ifr.ifr_name));
 
     // speed / duplex
@@ -614,20 +614,19 @@ psutil_net_if_duplex_speed(PyObject *self, PyObject *args) {
 
     close(sock);
     return Py_BuildValue("[ii]", duplex, speed);
-
-error:
-    if (sock != 0)
-        close(sock);
-    return PyErr_SetFromErrno(PyExc_OSError);
 }
 #endif  // net_if_stats() macOS/BSD implementation
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
 /*
  * define the psutil C module methods and initialize the module.
  */
-static PyMethodDef
-PsutilMethods[] = {
+static PyMethodDef mod_methods[] = {
     {"getpriority", psutil_posix_getpriority, METH_VARARGS,
      "Return process priority"},
     {"setpriority", psutil_posix_setpriority, METH_VARARGS,
@@ -645,66 +644,48 @@ PsutilMethods[] = {
     {NULL, NULL, 0, NULL}
 };
 
-struct module_state {
-    PyObject *error;
-};
 
 #if PY_MAJOR_VERSION >= 3
-#define GETSTATE(m) ((struct module_state*)PyModule_GetState(m))
-#else
-#define GETSTATE(m) (&_state)
-#endif
+    #define INITERR return NULL
 
-#if PY_MAJOR_VERSION >= 3
+    static struct PyModuleDef moduledef = {
+        PyModuleDef_HEAD_INIT,
+        "_psutil_posix",
+        NULL,
+        -1,
+        mod_methods,
+        NULL,
+        NULL,
+        NULL,
+        NULL
+    };
 
-static int
-psutil_posix_traverse(PyObject *m, visitproc visit, void *arg) {
-    Py_VISIT(GETSTATE(m)->error);
-    return 0;
-}
+    PyObject *PyInit__psutil_posix(void)
+#else  /* PY_MAJOR_VERSION */
+    #define INITERR return
 
-
-static int
-psutil_posix_clear(PyObject *m) {
-    Py_CLEAR(GETSTATE(m)->error);
-    return 0;
-}
-
-static struct PyModuleDef moduledef = {
-    PyModuleDef_HEAD_INIT,
-    "psutil_posix",
-    NULL,
-    sizeof(struct module_state),
-    PsutilMethods,
-    NULL,
-    psutil_posix_traverse,
-    psutil_posix_clear,
-    NULL
-};
-
-#define INITERROR return NULL
-
-PyMODINIT_FUNC PyInit__psutil_posix(void)
-
-#else
-#define INITERROR return
-
-void init_psutil_posix(void)
-#endif
+    void init_psutil_posix(void)
+#endif  /* PY_MAJOR_VERSION */
 {
 #if PY_MAJOR_VERSION >= 3
-    PyObject *module = PyModule_Create(&moduledef);
+    PyObject *mod = PyModule_Create(&moduledef);
 #else
-    PyObject *module = Py_InitModule("_psutil_posix", PsutilMethods);
+    PyObject *mod = Py_InitModule("_psutil_posix", mod_methods);
 #endif
+    if (mod == NULL)
+        INITERR;
 
 #if defined(PSUTIL_BSD) || defined(PSUTIL_OSX) || defined(PSUTIL_SUNOS) || defined(PSUTIL_AIX)
-    PyModule_AddIntConstant(module, "AF_LINK", AF_LINK);
+    if (PyModule_AddIntConstant(mod, "AF_LINK", AF_LINK)) INITERR;
 #endif
 
-    if (module == NULL)
-        INITERROR;
+    if (mod == NULL)
+        INITERR;
 #if PY_MAJOR_VERSION >= 3
-    return module;
+    return mod;
 #endif
 }
+
+#ifdef __cplusplus
+}
+#endif
